@@ -11,6 +11,9 @@ require DynaLoader;
 
 our @ISA = qw( DynaLoader Search::Xapian::Weight);
 
+# In a new thread, copy objects of this class to unblessed, undef values.
+sub CLONE_SKIP { 1 }
+
 sub new {
   my $class = shift;
   my $weight;
@@ -29,6 +32,8 @@ sub new {
 
 1;
 
+__END__
+
 =head1 NAME
 
 Search::Xapian::TradWeight - Traditional Probabilistic Weighting scheme.
@@ -54,4 +59,3 @@ If k isn't specified, the default value used is 1.
 L<Search::Xapian>,L<Search::Xapian::Enquire>
 
 =cut
-
